==> haskell-safecopy-0.10.4.3-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safecopy
version:              0.10.4.3
visibility:           public
id:                   safecopy-0.10.4.3-48VAxb81u6f6qu5A4k8crJ
key:                  safecopy-0.10.4.3-48VAxb81u6f6qu5A4k8crJ
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>, David Fox <dsf@seereason.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  de377e304771ab256922fc4bb46d037e
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safecopy
hs-libraries:         HSsafecopy-0.10.4.3-48VAxb81u6f6qu5A4k8crJ
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    generic-data-1.1.0.2-Kx3qLb9zoEZ33ZJUt01QNI
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    vector-0.13.2.0-7UWGIXxclbLLOjGg0s2qXt

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safecopy-0.10.4.3-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safecopy
version:              0.10.4.3
visibility:           public
id:                   safecopy-0.10.4.3-JjXeZxvFHC8LKu5SSnl7lS
key:                  safecopy-0.10.4.3-JjXeZxvFHC8LKu5SSnl7lS
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>, David Fox <dsf@seereason.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  f8c71135f25bdceb5ff6bb501af1a921
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safecopy
hs-libraries:         HSsafecopy-0.10.4.3-JjXeZxvFHC8LKu5SSnl7lS
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    generic-data-1.1.0.2-IYbzNA7WUJELew6nidpgAd
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    vector-0.13.2.0-7UWGIXxclbLLOjGg0s2qXt

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
